search

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 5, 2026 License: MIT Imports: 1 Imported by: 0

Documentation

Overview

Package search provides substring filtering and fuzzy key suggestions.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Filter

func Filter(term string, keys []string) []string

Filter returns the subset of keys that contain term (case-insensitive).

func Suggest

func Suggest(query string, candidates []string, maxResults int) []string

Suggest returns up to maxResults keys from candidates that are closest to query, ranked by a combined score: substring matches first, then by Levenshtein distance. Candidates with a distance greater than the adaptive threshold are excluded.

Types

This section is empty.

Jump to